@@ -387,7 +387,7 @@ class UnaryOpExpression : public Expression
 public:
 	virtual std::string getText(const std::string& indent = std::string{}) const override
 	{
-		if (_op->getType() == TokenType::NOT)
+		if (_op->getType() == TokenType::NOT || _op->getType() == TokenType::DEFINED)
 			return _op->getString() + " " + _expr->getText(indent);
 		else
 			return _op->getString() + _expr->getText(indent);
@@ -439,6 +439,26 @@ public:
 	}
 };
 
+/**
+ * Class representing defined operation.
+ *
+ * For example:
+ * @code
+ * defined @str
+ * @endcode
+ */
+class DefinedExpression : public UnaryOpExpression
+{
+public:
+	template<typename ExpPtr>
+	DefinedExpression(TokenIt op, ExpPtr &&expr) : UnaryOpExpression(op, std::forward<ExpPtr>(expr)) {}
+
+	virtual VisitResult accept(Visitor *v) override
+	{
+		return v->visit(this);
+	}
+};
+
 /**
  * Class representing unary minus operation.
  *
@@ -713,7 +733,7 @@ public:
  *
  * For example:
  * @code
- * pe.sections[0] matches /(text|data)/
+ * pe.sections[0].name matches /(text|data)/
  * @endcode
  */
 class MatchesExpression : public BinaryOpExpression
@@ -728,6 +748,26 @@ public:
 	}
 };
 
+/**
+ * Class representing iequals operation for case-insensitive string compare.
+ *
+ * For example:
+ * @code
+ * pe.sections[0].name iequals ".TEXT"
+ * @endcode
+ */
+class IequalsExpression : public BinaryOpExpression
+{
+public:
+	template <typename ExpPtr1, typename ExpPtr2>
+	IequalsExpression(ExpPtr1&& left, TokenIt op, ExpPtr2&& right) : BinaryOpExpression(std::forward<ExpPtr1>(left), op, std::forward<ExpPtr2>(right)) {}
+
+	virtual VisitResult accept(Visitor* v) override
+	{
+		return v->visit(this);
+	}
+};
+
 /**
  * Class representing arithmetic plus operation.
  *
