@@ -150,6 +150,11 @@ public:
 		return _handleUnaryOperation(expr);
 	}
 
+	virtual VisitResult visit(DefinedExpression *expr) override
+	{
+		return _handleUnaryOperation(expr);
+	}
+
 	virtual VisitResult visit(UnaryMinusExpression* expr) override
 	{
 		return _handleUnaryOperation(expr);
@@ -210,6 +215,11 @@ public:
 		return _handleBinaryOperation(expr);
 	}
 
+	virtual VisitResult visit(IequalsExpression* expr) override
+	{
+		return _handleBinaryOperation(expr);
+	}
+
 	virtual VisitResult visit(PlusExpression* expr) override
 	{
 		return _handleBinaryOperation(expr);
