@@ -72,6 +72,12 @@ public:
 		return {};
 	}
 
+	virtual VisitResult visit(DefinedExpression *expr) override
+	{
+		expr->getOperand()->accept(this);
+		return {};
+	}
+
 	virtual VisitResult visit(UnaryMinusExpression* expr) override
 	{
 		expr->getOperand()->accept(this);
@@ -154,6 +160,13 @@ public:
 		return {};
 	}
 
+	virtual VisitResult visit(IequalsExpression* expr) override
+	{
+		expr->getLeftOperand()->accept(this);
+		expr->getRightOperand()->accept(this);
+		return {};
+	}
+
 	virtual VisitResult visit(PlusExpression* expr) override
 	{
 		expr->getLeftOperand()->accept(this);
