@@ -529,6 +529,35 @@ YaraExpressionBuilder& YaraExpressionBuilder::matches(const YaraExpressionBuilde
 	return *this;
 }
 
+/**
+ * Applies operation iequals on two expression.
+ *
+ * @param other The other expression.
+ *
+ * @return Builder.
+ */
+YaraExpressionBuilder& YaraExpressionBuilder::iequals(const YaraExpressionBuilder& other)
+{
+	TokenIt token = _tokenStream->emplace_back(TokenType::IEQUALS, "iequals");
+	_tokenStream->moveAppend(other.getTokenStream());
+
+	_expr = std::make_shared<IequalsExpression>(std::move(_expr), token, other.get());
+	setType(Expression::Type::Bool);
+	return *this;
+}
+
+/**
+ * Applies operation defined on two expression.
+ *
+ * @return Builder.
+ */
+YaraExpressionBuilder& YaraExpressionBuilder::defined() {
+	auto token = _tokenStream->emplace(_tokenStream->begin(), TokenType::DEFINED, "defined");
+	_expr = std::make_shared<DefinedExpression>(token, std::move(_expr));
+	setType(Expression::Type::Int);
+	return *this;
+}
+
 /**
  * Accesses the attribute of a structure expression.
  *
