@@ -36,6 +36,7 @@ public:
 	PURE_VISIT(StringOffsetExpression)
 	PURE_VISIT(StringLengthExpression)
 	PURE_VISIT(NotExpression)
+	PURE_VISIT(DefinedExpression)
 	PURE_VISIT(UnaryMinusExpression)
 	PURE_VISIT(BitwiseNotExpression)
 	PURE_VISIT(AndExpression)
@@ -48,6 +49,7 @@ public:
 	PURE_VISIT(NeqExpression)
 	PURE_VISIT(ContainsExpression)
 	PURE_VISIT(MatchesExpression)
+	PURE_VISIT(IequalsExpression)
 	PURE_VISIT(PlusExpression)
 	PURE_VISIT(MinusExpression)
 	PURE_VISIT(MultiplyExpression)
@@ -107,6 +109,7 @@ public:
 	VISIT(ObservingVisitor, StringOffsetExpression)
 	VISIT(ObservingVisitor, StringLengthExpression)
 	VISIT(ObservingVisitor, NotExpression)
+	VISIT(ObservingVisitor, DefinedExpression)
 	VISIT(ObservingVisitor, UnaryMinusExpression)
 	VISIT(ObservingVisitor, BitwiseNotExpression)
 	VISIT(ObservingVisitor, AndExpression)
@@ -119,6 +122,7 @@ public:
 	VISIT(ObservingVisitor, NeqExpression)
 	VISIT(ObservingVisitor, ContainsExpression)
 	VISIT(ObservingVisitor, MatchesExpression)
+	VISIT(ObservingVisitor, IequalsExpression)
 	VISIT(ObservingVisitor, PlusExpression)
 	VISIT(ObservingVisitor, MinusExpression)
 	VISIT(ObservingVisitor, MultiplyExpression)
@@ -167,6 +171,7 @@ public:
 	VISIT(ModifyingVisitor, StringOffsetExpression)
 	VISIT(ModifyingVisitor, StringLengthExpression)
 	VISIT(ModifyingVisitor, NotExpression)
+	VISIT(ModifyingVisitor, DefinedExpression)
 	VISIT(ModifyingVisitor, UnaryMinusExpression)
 	VISIT(ModifyingVisitor, BitwiseNotExpression)
 	VISIT(ModifyingVisitor, AndExpression)
@@ -179,6 +184,7 @@ public:
 	VISIT(ModifyingVisitor, NeqExpression)
 	VISIT(ModifyingVisitor, ContainsExpression)
 	VISIT(ModifyingVisitor, MatchesExpression)
+	VISIT(ModifyingVisitor, IequalsExpression)
 	VISIT(ModifyingVisitor, PlusExpression)
 	VISIT(ModifyingVisitor, MinusExpression)
 	VISIT(ModifyingVisitor, MultiplyExpression)
