@@ -80,6 +80,10 @@ void addEnums(py::module& module)
 		.value("Kilobytes", IntMultiplier::Kilobytes)
 		.value("Megabytes", IntMultiplier::Megabytes);
 
+	py::enum_<IntFunctionEndianness>(module, "IntFunctionEndianness")
+		.value("Little", IntFunctionEndianness::Little)
+		.value("Big", IntFunctionEndianness::Big);
+
 	py::enum_<Rule::Modifier>(module, "RuleModifier")
 		.value("Empty", Rule::Modifier::None)
 		.value("Global", Rule::Modifier::Global)
@@ -180,6 +184,7 @@ void addEnums(py::module& module)
 		.value("ImportModule", TokenType::IMPORT_MODULE)
 		.value("ImportKeyword", TokenType::IMPORT_KEYWORD)
 		.value("Not", TokenType::NOT)
+		.value("Defined", TokenType::DEFINED)
 		.value("And", TokenType::AND)
 		.value("Or", TokenType::OR)
 		.value("All", TokenType::ALL)
@@ -193,6 +198,7 @@ void addEnums(py::module& module)
 		.value("Filesize", TokenType::FILESIZE)
 		.value("Contains", TokenType::CONTAINS)
 		.value("Matches", TokenType::MATCHES)
+		.value("Iequals", TokenType::IEQUALS)
 		.value("Slash", TokenType::SLASH)
 		.value("StringLiteral", TokenType::STRING_LITERAL)
 		.value("Integer", TokenType::INTEGER)
@@ -582,6 +588,7 @@ void addExpressionClasses(py::module& module)
 				&UnaryOpExpression::getOperand,
 				py::overload_cast<const Expression::Ptr&>(&UnaryOpExpression::setOperand));
 	unaryOpClass<NotExpression>(module, "NotExpression");
+	unaryOpClass<DefinedExpression>(module, "DefinedExpression");
 	unaryOpClass<UnaryMinusExpression>(module, "UnaryMinusExpression");
 	unaryOpClass<BitwiseNotExpression>(module, "BitwiseNotExpression");
 
@@ -602,6 +609,7 @@ void addExpressionClasses(py::module& module)
 	binaryOpClass<NeqExpression>(module, "NeqExpression");
 	binaryOpClass<ContainsExpression>(module, "ContainsExpression");
 	binaryOpClass<MatchesExpression>(module, "MatchesExpression");
+	binaryOpClass<IequalsExpression>(module, "IequalsExpression");
 	binaryOpClass<PlusExpression>(module, "PlusExpression");
 	binaryOpClass<MinusExpression>(module, "MinusExpression");
 	binaryOpClass<MultiplyExpression>(module, "MultiplyExpression");
@@ -816,6 +824,8 @@ void addBuilderClasses(py::module& module)
 		.def("comment", &YaraExpressionBuilder::comment, py::arg("message"), py::arg("multiline") = false, py::arg("indent") = "")
 		.def("contains", &YaraExpressionBuilder::contains)
 		.def("matches", &YaraExpressionBuilder::matches)
+		.def("iequals", &YaraExpressionBuilder::iequals)
+		.def("defined", &YaraExpressionBuilder::defined)
 		.def("read_int8", &YaraExpressionBuilder::readInt8)
 		.def("read_int16", &YaraExpressionBuilder::readInt16)
 		.def("read_int32", &YaraExpressionBuilder::readInt32)
