@@ -14,6 +14,34 @@
 
 namespace yaramod {
 
+
+std::string Token::getText(bool pure) const
+{
+	auto output = _value->getText(pure);
+	size_t changed_index = pure ? 0 : 1;
+	if (_type == TokenType::STRING_LENGTH)
+	{
+		assert(output.size() > changed_index);
+		output[changed_index] = '!';
+	}
+	else if (_type == TokenType::STRING_OFFSET)
+	{
+		assert(output.size() > changed_index);
+		output[changed_index] = '@';
+	}
+	else if (_type == TokenType::STRING_COUNT)
+	{
+		assert(output.size() > changed_index);
+		output[changed_index] = '#';
+	}
+	return output;
+}
+
+std::string Token::getPureText() const
+{
+	return getText(true);
+}
+
 const Literal& Token::getLiteral() const
 {
 	assert("Literal is not nullptr" && _value);
@@ -27,6 +55,7 @@ const std::string& Token::getString() const
 
 bool Token::getBool() const
 {
+	assert(isBool()); 
 	return _value->getBool();
 }
 
@@ -50,6 +79,11 @@ const std::shared_ptr<Symbol>& Token::getSymbol() const
 	return _value->getSymbol();
 }
 
+Literal::ReferenceType Token::getLiteralReference() const
+{
+	return _value->getLiteralReference();
+}
+
 const std::shared_ptr<TokenStream>& Token::getSubTokenStream() const
 {
 	return _subTokenStream;
